function [r_obs, ppi_obs, g_obs] = history(et)

% history.m
%
% Takes in a history of shocks and constructs a history for 
% r ppi and g
%
%  

%% Parameters of the simulation
doplots = 1;
ta = 140; % Time of the announcement
T = 20;  % Implementation of the change at T + ta

modelbp;

%% Constructs a stochastic simulation with foreseen changes (same history)

[junk horizon] = size(et);
%  et = 0*et; % Uncomment to compute the non-stochastic transition.


%% Use initial structure to simulate data up to period ta;
y = zeros(nvars,horizon);
y(:,1) = y_ss;

for t = 2:ta-1
    y(:,t) = Q * y(:,t-1) + G*et(:,t);
end

%% Compute transition period
A0inv = A0\eye(nvars);
A = A0\A1;
B = A0\B0;
% Construct sequences of time-varying matrices
A0s = repmat(A0,T,1);
A0invs = repmat(A0inv,T,1);
A1s = repmat(A1,T,1);
B0s = repmat(B0,T,1);
As = repmat(A,T,1);
Bs = repmat(B,T,1);
Qt = zeros(nvars,nvars,T);
Gt = zeros(nvars,nshocks,T);

% Compute C_T
Qt(:,:,end) = (eye(nvars)-Bs(end-nvars+1:end,:)*Qf)\As(end-nvars+1:end,:);
Gt(:,:,end) = (eye(nvars)-Bs(end-nvars+1:end,:)*Qf)\A0invs(end-nvars+1:end,:)*D0;

% Remember to write this generally to accomodate variation in A and B
for t = T-1:-1:1,
    Qt(:,:,t) = (eye(nvars)-B*Qt(:,:,t+1))\A;
    Gt(:,:,t) = (eye(nvars)-B*Qt(:,:,t+1))\A0inv*D0;
end

for t = ta:(T+ta-1)
    y(:,t) = Qt(:,:,t-ta+1) * y(:,t-1) + Gt(:,:,t-ta+1) * et(:,t);
end

%%
for t = T+ta:horizon
    y(:,t) = Qf * y(:,t-1) + Gf * et(:,t);
end

r_obs = y(r,:);
ppi_obs = y(ppi,:);
g_obs = y(g,:);

if doplots
    time = 1:horizon;
    subplot(2,2,1), plot(time,y(r,:)), title('Nominal Interest Rate')
    subplot(2,2,2), plot(time,y(ppi,:)), title('Inflation Rate')
    subplot(2,2,3), plot(time,y(g,:)), title('Growth')
    subplot(2,2,4), plot(time,y(x,:)), title('Output gap')
end

